<?php

// Menú de opciones en el admin
add_action('admin_menu', 'uli_super_cache_cleaner_menu');

function uli_super_cache_cleaner_menu() {
    add_options_page('Uli Super Cache Cleaner', 'Uli Super Cache Cleaner', 'manage_options', 'uli-super-cache-cleaner', 'uli_super_cache_cleaner_options_page');
}

// Página de opciones
function uli_super_cache_cleaner_options_page() {
?>
    <div class="wrap">
        <h1>Uli Super Cache Cleaner</h1>
        <form method="post" action="options.php">
            <?php settings_fields('uli_super_cache_cleaner_options_group'); ?>
            <?php do_settings_sections('uli-super-cache-cleaner'); ?>
            <?php submit_button(); ?>
        </form>
    </div>
<?php
}

add_action('admin_init', 'uli_super_cache_cleaner_settings');

function uli_super_cache_cleaner_settings() {
    register_setting('uli_super_cache_cleaner_options_group', 'uli_super_cache_cleaner_schedule');
    register_setting('uli_super_cache_cleaner_options_group', 'uli_super_cache_cleaner_max_size');
    
    add_settings_section('uli_super_cache_cleaner_main_section', '', null, 'uli-super-cache-cleaner');

    add_settings_field('uli_super_cache_cleaner_schedule_field', 'Frecuencia de limpieza (en minutos):', 'uli_super_cache_cleaner_schedule_field_callback', 'uli-super-cache-cleaner', 'uli_super_cache_cleaner_main_section');
    add_settings_field('uli_super_cache_cleaner_max_size_field', 'Tamaño máximo de la caché (en MB):', 'uli_super_cache_cleaner_max_size_field_callback', 'uli-super-cache-cleaner', 'uli_super_cache_cleaner_main_section');
}

function uli_super_cache_cleaner_schedule_field_callback() {
    $schedule = get_option('uli_super_cache_cleaner_schedule', '1440');
    echo '<input type="number" name="uli_super_cache_cleaner_schedule" value="' . $schedule . '" min="1" />';
}

function uli_super_cache_cleaner_max_size_field_callback() {
    $max_size = get_option('uli_super_cache_cleaner_max_size', '50');
    echo '<input type="number" name="uli_super_cache_cleaner_max_size" value="' . $max_size . '" min="1" />';
}

// Actualizar tarea programada según configuración
add_action('update_option_uli_super_cache_cleaner_schedule', 'uli_super_cache_cleaner_update_schedule', 10, 2);

function uli_super_cache_cleaner_update_schedule() {
    wp_clear_scheduled_hook('wp_uli_cleaner_cache');
    $schedule = get_option('uli_super_cache_cleaner_schedule', '1440');
    wp_schedule_event(time(), 'custom_interval', 'wp_uli_cleaner_cache');
}

// Añadir intervalo personalizado para cron
add_filter('cron_schedules', 'uli_super_cache_cleaner_cron_schedules');

function uli_super_cache_cleaner_cron_schedules($schedules) {
    $schedule = get_option('uli_super_cache_cleaner_schedule', '1440');
    $schedules['custom_interval'] = array(
        'interval' => $schedule * 60, // Convertir minutos a segundos
        'display'  => __('Custom Interval', 'textdomain')
    );
    return $schedules;
}
